agentle.mcp.prompts.prompt\_argument
====================================

.. automodule:: agentle.mcp.prompts.prompt_argument

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      PromptArgument
   